Monty Python's Flying Circus: Just the Words - Episode 24

# Episode Twenty-four

Conquistador Coffee Campaign
Repeating groove
Ramsay MacDonald striptease
Job Hunter
Agatha Christie Sketch (Railway Timetables)
Mr Neville Shunt
Film director (teeth)
City gents vox pops
'Crackpot Religions Ltd'
'How not to be seen'
Crossing the Atlantic on a tricycle
Interview in filing cabinet
'Yummy yummy'
Monty Python's Flying Circus again in thirty seconds

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| An office. Boss is reading a book, 'Chinese for Business Men'. He tries out a few Chinese words. There is a knock at the door.
Boss | Come in. (Mr Frog comes in) Ah, Frog.
Frog | S. Frog, sir.
Boss | Shut up, I want to have a word with you, Frog.
Frog | S. Frog, sir.
Boss | Shut up. It's about your advertising campaign for Conquistador Coffee. Now, I've had the managing director of Conquistador to see me this morning and he's very unhappy with your campaign. Very unhappy. In fact, he's shot himself.
Frog | Badly, sir?
Boss | No, extremely well. (lifts up a leg belonging to a body behind desk, and holds up a card saying 'joke') Well, before he went he left a note with the company secretary (opens a nearby door; a dead company secretary falls out), the effect of which was how disappointed he was with your work and, in particular, why you had changed the name from Conquistador Instant Coffee to Conquistador Instant Leprosy. Why, Frog?
Frog | S. Frog, sir.
Boss | Shut up. Why did you do it?
Frog | It was a joke.
Boss | A joke? (holds up card saying 'joke')
Frog | No, no not a joke, a sales campaign. (holds up a card saying 'No, a Sales Campaign')
Boss | I see, Frog.
Frog | S. Frog, sir.
Boss | Shut up. Now, let's have a look at the sales chart. (indicates a plummeting sales graph) When you took over this account, Frog, Conquistador was a brand leader. Here you introduced your first campaign, 'Conquistador Coffee brings a new meaning to the word vomit'. Here you made your special introductory offer of a free dead dog with every jar, and this followed your second campaign 'the tingling fresh coffee which brings you exciting new cholera, mange, dropsy, the clap, hard pad and athlete's head. From the House of Conquistador'.
Frog | It was a soft-sell, sir
Boss | Why, Frog?
Frog | S. Frog, sir.
Boss | Shut up! Well?
Frog | Well, people know the name, sir.
Boss | They certainly do know the name - they burnt the factory down. The owner is hiding in my bathroom (shot heard) - the owner was hiding in my bathroom. (holds up 'joke' card again)
Frog | You're not going to fire me, sir?
Boss | Fire you? Three men dead, the factory burnt down, the account lost and our firm completely bankrupt, what... what... what ... can you possibly say? What excuse can you possibly make?
Frog | Sorry, father. (holds up the 'joke' card)
Boss | Oh, yes. Oh, incidentally your film's won a prize.
| He opens a venetian blind on the window to reveal the film: a coastline. Panning shot of hills rolling down into the sea, waves breaking on the shore. Travelogue music. Suddenly the music sticks, and keeps repeating one phrase. The pan continues. We come across an old-fashioned gramophone on which the record is sticking. A hand comes in and lifts the needle off. The pan continues - it's the hand of the announcer who is sitting at his desk.
Announcer | Sorry about that. And now for something completely diff... (the film sticks and repeats the end of the sentence several times) something completely diff... completely diff... completely diff... completely diff... completely different.
It's Man | It's...
| After about fifteen seconds of the credits the music and animation sticks, and keeps repeating. We finally get on to the right track, and complete the titles. Stock film of Ramsay MacDonald arriving at Number 10 Downing Street and any others of that period.
Voice Over | 1929. Stanley Baldwin's Conservative Government is defeated and Ramsay MacDonald becomes, for the second time, Prime Minister of England.
| MacDonald walks into an empty room - black and white film.
Ramsay MacDonald | My, it's hot in here.
| He proceeds to take off his clothes, strips down to black garter belt and suspenders and stocking.
| Cut to Mr Glans who is sitting next to a fully practical old 8mm home projector. There is a knock at the door. He switches the projector off and hides it furtively. He is sitting in an office, with a placard saying 'Exchange and Mart, Editor' on his desk. He points to it rather obvoiusly.
Glans | Hello, come in. (enter Bee, a young aspirant job hunter) Ah, hello, hello, how much do you want for that briefcase?
Bee | Well, I...
Glans | All right then, the briefcase and the umbrella. A fiver down, must be my final offer.
Bee | Well, I don't want to sell them. I've come for a job.
Glans | Oh, take a seat, take a seat.
Bee | Thank you.
Glans | I see you chose the canvas chair with the aluminium frame. I'll throw that in and a fiver, for the briefcase and the umbrella ... no, make it fair, the briefcase and the umbrella and the two pens in your breast pocket and the chair's yours and a fiver and a pair of ex-German U-boat commander's binoculars.
Bee | Really, they are not for sale.
Glans | Not for sale, what does that mean?
Bee | I came about the advertisement for the job of assistant editor.
Glans | Oh yeah, right. Ah, OK, ah. How much experience in journalism?
Bee | Five years.
Glans | Right, typing speed?
Bee | Fifty.
Glans | O Levels?
Bee | Eight.
Glans | A Levels?
Bee | Two.
Glans | Right... Well, I'll give you the job, and the chair, and an all-wool ex-army sleeping bag ... for the briefcase, umbrella, the pens in your breast pocket and your string vest.
Bee | When do I start?
Glans | Monday.
Bee | That's marvellous.
Glans | If you throw in the shoes as well. (presses intercom) Hello, er ... Miss Johnson? Could we have two coffees and biscuits please?
Miss Johnson | (over intercom) One coffee and one biscuit for the two ex-army greatcoats and the alarm clock on the mantelpiece.
Glans | Two ex-army greatcoats and the alarm clock and a table lamp, for two coffees and biscuits.
| ANIMATION: an elderly secretary at a desk in an empty room.
Miss Johnson | Two greatcoats and two table lamps.
| Cut back to real office.
Glans | Two greatcoats, one table lamp and a desert boat.
| Cut back to cartoon.
Miss Johnson | For two coffees and biscuits? Office.
Glans | Done. Cartoon.
Miss Johnson | Done.
Voice Over | So Miss Johnson returned to her typing and dreamed her little dreamy dreams, unaware as she was of the cruel trick fate had in store for her. For Miss Johnson was about to fall victim of the dreaded international Chinese Communist Conspiracy. (lots of little yellow men pour into the office) Yes, these fanatical thieves under the leadership of the so-called Mao Tse-tung (who appears in the animation) had caught Miss Johnson off guard for one brief but fatal moment and destroyed her. (Miss Johnson is submerged in a tide of yellow men) Just as they are ready to do anytime free men anywhere waver in their defence of democracy.
| A sailing ship with American flag sails in over yellow men. Zoom in on the flag: Uncle Sam appears in front of it.
Uncle Sam | Yes, once again American defence proves its effectiveness against international communism. Using this diagram of a tooth to represent any small country, we can see how international communism works by eroding away form the inside (diagram of tooth rotting from inside and collapsing) When one country or tooth falls victim to international communism, its neighbours soon follow. (the remaining teeth fall sideways into the gap) In dentistry, this is known as Domino Theory. but with american defence the decay is stopped before it starts and that's why nine out of ten small countries choose American defense ...
Different Voice Over | ... Or Crelm toothpaste with the miracle ingredient, Fraudulin! The white car represents Crelm toothpaste with the miracle ingredient, Fraudulin. (two cars in a bleak landscape) The non-white car represents another toothpaste. (the cars race of) Both toothpastes provide 30% protection. (they pass a banner: '60% protection') At 60% protection both toothpastes are doing well. And now at 90% protection the ... wait! (the grey car stops dead at the '90% protection' banner) The non-white car is out, and the Crelm toothpaste goes on to win with 100% protection! Yes, do like all smart motorists. Choose Crelm toothpaste.
| Cut to 'Shrill' advertising man
'Shrill' Man | Or Shrill Petrol with the new addititve GLC 9424075. After 6 p.m., 9424047. Using this white card (half of screen goes white) to represent Shrill's new additive GLC 9424075 - after 6 p.m., 9424047 - we can see how the engine deposits are pushed off the face of the earth by the superior forces available to Shrill. (shot, off) Aaaagh!
| End of animation. Cut to an upper-class drawing room. An elderly man lies dead on the floor. Enter Jasmina and John.
Jasmina | Anyway, John, you can catch the 11.30 from Hornchurch and be in Basingstoke by one o'clock, oh, and there's a buffet car and... (sees corpse) Oh! Daddy!
John | My hat! Sir Horace!
Jasmina | (not daring to look) Has he been...
John | Yes - after breakfast. But that doesn't matter now... he's dead.
Jasmina | Oh! Poor daddy...
John | Looks like I shan't be catching the 11.30 now.
Jasmina | Oh no, John, you mustn't miss your train.
John | How could I think of catching a train when I should be here helping you?
Jasmina | Oh, John, thank you... anyway you could always catch the 9.30 tomorrow - it goes via Caterham and Chipstead.
John | Or the 9.45's even better.
Jasmina | Oh, but you'd have to change at Lambs Green.
John | Yes, but there's only a seven-minute wait now.
Jasmina | Oh, yes, of course, I'd forgotten it was Friday. Oh, who could have done this?
| Enter Lady Partridge.
Lady Partridge | Oh, do hurry Sir Horace, your train leaves in twenty-eight minutes, and if you miss the 10.15 you won't catch the 3.45 which means ... oh!
John | I'm afraid Sir Horace won't be catching the 10.15, Lady Partridge.
Lady Partridge | Has he been... ?
Jasmina | Yes - after breakfast.
John | Lady Partridge, I'm afraid you can cancel his seat reservation.
Lady Partridge | Oh, and it was back to the engine - fourth coach along so that he could see the gradient signs outside Swanborough.
John | Not any more Lady Partridge... the line's been closed.
Lady Partridge | Closed! Not Swanborough!
John | I'm afraid so.
| Enter Inspector Davis.
Inspector | All right, nobody move. I'm Inspector Davis of Scotland Yard.
John | My word, you were here quickly, inspector.
Inspector | Yeah, I got the 8.55 Pullman Express from King's Cross and missed that bit around Hornchurch.
Lady Partridge | It's a very good train.
All | Excellent, very good, delightful.
| Tony runs in through the french windows. He wears white flannels and boater and is jolly upper-class.
Tony | Hello everyone.
All | Tony!
Tony | Where's daddy? (seeing him) Oh golly! Has he been... ?
John and Jasmina | Yes, after breakfast.
Tony | Then ... he won't be needing his reservation on the 10.15.
John | Exactly.
Tony | And I suppose as his eldest son it must go to me.
Inspector | Just a minute, Tony. There's a small matter of... murder.
Tony | Oh, but surely he simply shot himself and then hid the gun.
Lady Partridge | How could anyone shoot himself and then hide the gun without first cancelling his reservation.
Tony | Ha, ha! Well, I must dash or I'll be late for the 10.15.
Inspector | I suggest you murdered your father for his seat reservation.
Tony | I may have had the motive, inspector, but I could not have done it, for I have only just arrived from Gillingham on the 8.13 and here's my restaurant car ticket to prove it.
Jasmina | The 8.13 from Gillingham doesn't have a restaurant car.
John | It's a standing buffet only.
Tony | Oh, er... did I say the 8.13, I meant the 7.58 stopping train.
Lady Partridge | But the 7.58 stopping train arrived at Swindon at 8.19 owing to annual point maintenance at Wisborough Junction.
John | So how did you make the connection with the 8.13 which left six minutes earlier?
Tony | Oh, er, simple! I caught the 7.16 Football Special arriving at Swindon at 8.09.
Jasmina | But the 7.16 Football Special only stops at Swindon on alternate Saturdays.
Lady Partridge | Yes, surely you mean the Holidaymaker Special.
Tony | Oh, yes! How daft of me. Of course, I came on the Holidaymaker Special calling at Bedford, Colmworth, Fen Dinon, Sutton, Wallington and Gillingham.
Inspector | That's Sundays only!
Tony | Damn. All right, I confess I did it. I killed him for his reservation, but you won't take me alive! I'm going to throw myself under the 10.12 from Reading.
John | Don't be a fool, Tony, don't do it, the 10.12 has the new narrow traction bogies, you wouldn't stand a chance.
Tony | Exactly.
| Tableau. Loud chord and slow curtain.
Voice Over | That was an excerpt from the latest West End hit 'It all happened on the 11.20 from Hainault to Redhill via Horsham and Reigate, calling at Carshalton Beeches, Malmesbury, Tooting Bec, and Croydon West'. The author is Mr. Neville Shunt.
| Shunt sitting among mass of railway junk, at typewriter, typing away madly.
Shunt | (typing) Chuff, chuff, chuffwoooooch, woooooch! Sssssssss, sssssssss! Diddledum, diddledum, diddlealum. Toot, toot. The train now standing at platform eight, tch, tch, tch, diddledum, diddledum. Chuffff chuffffiTff eeeeeeeeeaaaaaaaaa Vooooommmmm.
| Cut to art critic. SUPERIMPOSED CAPTION: 'GAVIN MILLARRRRRRRRRR'
Art Critic | Some people have made the mistake of seeing Shunt's work as a load of rubbish about railway timetables, but clever people like me, who talk loudly in restaurants, see this as a deliberate ambiguity, a plea for understanding in a mechanized world. The points are frozen, the beast is dead. What is the difference? What indeed is the point? The point is frozen, the beast is late out of Paddington. The point is taken. If La Fontaine's elk would spurn Tom Jones the engine must be our head, the dining car our oesophagus, the guard's van our left lung, the cattle truck our shins, the first-class compartment the piece of skin at the nape of the neck and the level crossing an electric elk called Simon. The clarity is devastating. But where is the ambiguity? It's over there in a box. Shunt is saying the 8.15 from Gillingham when in reality he means the 8.13 from Gillingham. The train is the same only the time is altered. Ecce homo, ergo elk. La Fontaine knew his sister and knew her bloody well. The point is taken, the beast is moulting, the fluff gets up your nose. The illusion is complete; it is reality, the reality is illusion and the ambiguity is the only truth. But is the truth, as Hitchcock observes, in the box? No there isn't room, the ambiguity has put on weight. The point is taken, the elk is dead, the beast stops at Swindon, Chabrol stops at nothing, I'm having treatment and La Fontaine can get knotted.
| Cut to man at desk.
Man | Gavin Millar...
| Cut to another man.
Another Man | ...rrrrrrr...
| Cut to first man.
Man | ... was not talking to Neville Shunt. From the world of the theatre we turn to the world of dental hygiene. No, no, no, no. From the world of the theatre we move to the silver screen. We honour one of the silver screen's outstanding writer-dentists... writer-directors, Martin Curry who is visiting London to have a tooth out, for the pre-molar, er... premiere of his filling, film next Toothday... Tuesday, at the Dental Theatre... Film Theatre. Martin Curry talking to Matthew Palate... Padget.
| Cut to late-night line-up setting. Interviewer and interviewee.
Padget | Martin Curry, welcome. One of the big teeth... big points that the American critics made about your latest film, 'The Twelve Caesars', was that it was on so all-embracing a topic. What made you undertake so enormous a tusk... task?
| We now see that his interviewee has two enormous front teeth.
Curry | Well I've always been interested in Imperial Rome from Julius Caesar right through to Vethpathian.
Padget | Who?
Curry | Vethpathian.
Padget | Ah! Vespasian.
Curry | Yes.
Padget | When I saw your film it did seem to me that you had taken a rather, umm, subjective approach to it.
Curry | I'm sorry?
Padget | Well, I mean all your main characters had these enormous ... well not enormous, these very big ... well let's have a look at a clip in which Julius Incisor .... Caesar talks to his generals during the battle against Caractacus.
Curry | I don't see that at all.
| Film: interior of a tent; generals around a table.
Labienus | (with relatively enormous front teeth) Shall I order the cavalry that they may hide themselves in the wood, O Caesar?
All | (with very large front teeth) Thus O Caesar.
Julius | (with amazingly large front teeth) Today is about to be a triumph for our native country.
| Back to interview set.
Padget | Martin Curry, why do all your characters have these very big er ... very big um ... teeth?
Curry | What do you mean?
Padget | Well, I mean, er... and even in your biblical epic, 'The Son of Man', John the Baptist had the most enormous ... dental appendages ... and of course ... himself had the most monumental ivories.
Curry | No, I'm afraid I don't see that at all. (picks up glass of water but can't get it to his mouth) Could I have a straw?
Padget | Oh, a straw, yes, yes. Well while we're doing that perhaps we could take another look at an earlier film, 'Trafalgar'.
| Between decks. Nelson lying among others. They all have enormous teeth.
Nelson | Cover my coat, Mr Bush, the men must not know of this till victory is ours.
Toad | The surgeon's coming, sir.
Nelson | No, tell the surgeon to attend the men that can be saved. He can do little for me, I fear.
Toad | Aye, aye, sir.
Nelson | Hardy! Hardy!
Hardy | Sir?
Nelson | Hardy...kiss... er ... put your hand on my thigh.
| Back to interview set. Curry is sitting practically upside down, trying to drink water with much difficulty
Padget | Martin Curry, thank you. Well. We asked the first-night audience what they thought of that film.
| Cut to vox pops.
Man With Enormous Ears | It wasn't true to life.
Man With Enormous Teeth | Yes it was.
Man With Enormous Nose | No it wasn't.
Madly Dressed Man | I thought it was totally bizarre.
First City Gent | Well I've been in the city for over forty years and I think the importance of looking after poor people cannot be understressed.
Second City Gent | Well I've been in the city for twenty years and I must admit - I'm lost.
An Old Gramophone | Well, I've been in the city all my life and I'm as alert and active as I've ever been.
Third City Gent | Well I've been in the city since I was two and I certainly wouldn't say that I was stuck in a rut... stuck in a rut ... stuck in a rut... stuck in a rut...
Woman | Oh dear, Mr Bulstrode's stuck again.
| She runs over and gives him a shove.
Third City Gent | I certainly wouldn't say that I was stuck in a rut.
Fourth City Gent | Well l've been in the city for thirty years and I've never once regretted being a nasty, greedy, cold hearted, avaricious, money-grubber ... Conservative.
Fifth City Gent | Well I've been in the city for twenty-seven years and I would like to see the reintroduction of flogging. Every Thursday, round at my place.
Man | (whose head only is visible above the level of the sea) Well I've been in the sea for thirty-three years and I've never regretted it.
| Camera pulls back to reveal other city gents also with only heads and bowlers visible who say 'quite agree'. Camera pulls back further to reveal an elderly couple sitting in deckchairs.
Man | I think it must be a naturalist outing.
Woman | I think it must be one of them crackpot religions.
| Cut to Arthur Crackpot sitting at a large curved desk on the front of which a sign says 'Crackpot Religions Ltd. Arthur Crackpot President and God (Ltd)'.
Crackpot | This is an example of the sort of abuse we get all the time from ignorant people. I inherited this religion from my father, an ex-used-car salesman and part-time window-box, and I am very proud to be in charge of the first religion with free gifts. You get this luxury tea-trolley with every new enrollment. (pictures of this and the subsequent gifts) In addition to this you can win a three-piece lounge suite, this luxury caravan, a weekend for two with Peter Bonetti and tonights star prize, the entire Norwich City Council.
| Curtains go up to reveal the council. Terrific 'ooh' from an audience. Bad organ chords played by a nude man.
Crackpot | And remember with only eight scoring draws you can win a bishopric in a see of your own choice. You see we have a much more modern approach to religion.
| Cut to a person in church. They are walking past a pillar. They take out some money and put it in a collecting box. A sign on the box says 'For the rich'. We hear the money going in, then it moves off, along pipes, falling down; eventually it comes down a small pipe and lands with a tinkle in Crackpot's ashtray. He tries the money with his teeth, pops it into his pocket, and finishes reading...
Crackpot | Blessed is Arthur Crackpot and all his subsidiaries Ltd. You see, in our Church we have a lot more fun.
Priest | (we see he has a pepperpot with him) Oh, Mrs Collins, you did say you were nervous, didn't you? You have eyes on the coffee machine?
Mrs Collins | I don't mind, I don't mind - it's just nice to be here, Reverend.
Priest | (slaps her) Archdeacon! You asked for the coffee machine ... so lets see what you've won. You chose Hymn no. 437. (goes to hymn board, removes one of the numbers, and reads what's on the back) Oh, Mrs Collins, you had eyes on the coffee machine. Well you have won tonight's star prize: the entire Norwich City Council.
| Organ music, oohs and applause from audience.
Mrs Collins | I've got one already. (the priest starts to throttle her)
| Cut back to Crackpot in his Office.
Crackpot | A lot of religions - no names no pack drill - do go for the poorer type of person - face it, there's more of 'em - poor people, thieves, villains, poor people without no money at all - well we don't have none of that. Rich people and crumpet over sixteen can enter free: upper middle class quite welcome; lower middle class not under five grand a year. Lower class - I can't touch it. There's no return on it, you see.
| Pull back to show interviewer sitting at his side.
Interviewer | Do you have any difficulty converting people?
Crackpot | Oh no, well we have ways of making them join.
| Cut to a photo of a bishops SUPERIMPOSED CAPTION: 'THE BISHOP OF DULWICH'
Crackpot's Voice | Norman there does a lot of converting: a lot of protection, that sort of thing. And there's his mate, Bruce Beer.
| Photo of Aussie bishop with beer can SUPERIMPOSED CAPTION: 'THE ARCHBISHOP OF AUSTRALIA'
Crackpot's Voice | Brucie has personally converted ninety-two people twenty-five inside the distance. Then again we're not afraid to use more modern methods.
| Cut to 'Daily Mirror' type pin-up of a bikinied lovely in a silly pose, on a beach with a bishop's mitre and Bible. A large headline reads 'North See Gas'. A subheading says 'Bishop Sarah', then below that, this blurb which is also read voice over.
Voice Over | Sarah, today's diocesan lovely is enough to make any chap go down on his knees. This twenty-three-year-old bishop hails appropriately enough from Bishop's Stortford and lists her hobbies as swimming, riding, and film producers. What a gas! Bet she's no novice when it comes to converting all in her See.
| Cut to Gumby in street. SUPERIMPOSED CAPTION: 'ARCHBISHOP GUMBY'
Gumby | (shouting laboriously) Basically, I believe in peace and bashing two bricks together. (he bashes two bricks together)
| Cut to John Lennon
Lennon | I'm starting a war for peace.
| Cut to Ken Shabby. SUPERIMPOSED CAPTION: 'ARCHBISHOP SHABBY'
Shabby | Cor blimey. I'm raising polecats for peace.
| Cut to Arthur Nudge. SUPERIMPOSED CAPTION: 'ARCHBISHOP NUDGE'
Nudge | Peace? I like a peace. Know what I mean? Know what I mean? Say no more. Nudge, nudge.
| Cut to a bishop. A sign on the wall says 'Naughty Religion '.
Bishop | Our religion is the first Church to cater for the naughty type of person. If you'd like a bit of 'love-your-neighbour' - and who doesn't now and again - then see Vera and Ciceley during the hymns.
| Cut to wide-boy Pope, with small moustache and kipper tie. A sign says: 'No Questions Asked Religion '.
Bill | In our Church we try to help people to help themselves - to cars, washing machines, lead piping, no questions asked. We are the only Church, apart from the Baptists, to do respray jobs.
| Cut to loony with a fright wig and an axe in his head. A sign says: 'The Lunatic Religion'.
Ali Byan | We at the Church of the Divine Loony believe in the power of prayer to turn the head purple ha, ha, ha.
| Cut to a normal looking priest. A sign says: 'The Most Popular Religion Ltd'.
Priest | I would like to come in here for a moment if I may, and disassociate our Church from these frivolous and offensive religions. We are primarily concerned with what is best... (phone rings; he answers it) Hello. Oh, well how about Allied Breweries? All right, but keep the Rio Tinto (puts phone down) ... for the human soul.
| ANIMATION: a vicar c/o Terry Gilliam CAPTION: 'CARTOON RELIGIONS LTD'
Voice | In our Church we believe first and foremost in you. (use smiles; the top of his head comes off and the Devil tries to climb out; the vicar replaces his head) We want you to think of us as your friend. (as before; the vicar nails the top of his head on)
Voice Over | In this picture there are forty people. None of them can be seen. In this film we hope to show how not to be seen.
| CAPTION: 'HM GOVERNMENT, PUBLIC SERVICE FILM NO. 42 PARA 6. 'HOW NOT TO BE SEEN''
Voice Over | This is Mr E. R. Bradshaw, of Napier Court, Black Lion Road, SE5. He cannot be seen. Now I'm going to ask him to stand up. Mr Bradshaw will you stand up please?
| In the middle distance a smiling holidaymaker in braces, collarless shirt and hankie, stands up. There is a pause. Only the sound of the wind. Then a loud gunshot rings out. Mr. Bradshaw crumples to the ground
Voice Over | This demonstrates the value of not being seen.
| Cut to another location - an empty area of scrubland
Voice Over | In this picture we canot see Mrs. B.J. Smegma of 13, The Cresent, Belmont. Mrs Smegma will you stand up please.
| There is a pause. Almost on the edge of the frame in the distance a pepperpot stands up, proudly. Immediately a shot rings out and she leaps in the air and dies. Cut to a bush some distance awy on open land
Voice Over | This is Mr Nesbitt of Harlow New Town. Mr Nesbit would you stand up please. (nothing happens) Mr Nesbitt has learnt the first lesson of not being seen. However he has chosen a very obvious piece of cover. (the bush explodes; cut to a shot of three bushes) Mr. E.V. Lambert of 'Homeleigh', The Burrows, Oswestry, has presented us with a poser. We do not know which bush he is behind, but we can soon find out. (the left-hand bush explodes, then the right-hand bush explodes, finally the middle bush explodes; there is a muffled scream; the smoke subsides) Yes it was the middle one.
| Cut to a shot of farmland. There is a waterbutt, a low wall, a big pile of leaves, a parked car and lots of bushes and trees in the distance
Voice Over | Mr Ken Andrews, of Leighton Road, Slough, has concealed himself extremely well. He could be almost anywhere. He could be behind the wall, inside the water barrel, beneath a pile of leaves, up in the tree, squatting down behind the car, concealed in a hollow, or crouched behind any one of a hundred bushes. However we happen to know he's in the water barrel.
| The water barrel just blows up in the biggest explosion yet. Cut to a panning shot from beach huts accross to beach and sea
Voice Over | Mr. and Mrs. Watson of 'Ivy Cottage', Worplesdon Road, Hull, chose a very cunning way of not being seen. When we called at their house, we found that they had gone away on two weeks holiday. They had not left any forwading address, and they had bolted and barred the house to prevent us getting in. However a neighbour told us where there were.
| The camera has come to rest on a very obvious isolated beach hut; it blows up. Cut to a building site in a suburban housing estate. There is a Gumby standing there.
Voice Over | And here is the neighbour who told us where they were (he blows up) Nobody likes a clever dick. (cut to stock film of a small house) Here is where he lived (it blows up) And this is where Lord Langdon lived who refused to speak to us (it blows up). So did the gentleman who lived here....(shot of house: it blows up)... and here ...(ditto) and of course here.....(a series of quick cuts of various atom bombs and hydrogen bomb at moment of impact) and Manchester and the West Midlands, Spain, China ...(mad laugh)
| Cut to a presentation desk. The film is on a screen behind. We see it stop behind him as the presenter speaks.
Presenter | Ah, well I'm afraid we have to stop the film there, as some of the scenes which followed were of a violent nature which might have proved distressing to some of our viewers. Though not to me, I can tell you. (cut to another camera; the presenter turns to face it,) In Nova Scotia today, Mr Roy Bent of North Walsham in Norfolk became the first man to cross the Atlantic on a tricycle. His tricycle, specially adapted for the crossing, was ninety feet long, with a protective steel hull, three funnels, seventeen first-class cabins and a radar scanner. (A head and shoulders picture of Roy Bent comes up on the screen behind him) Mr Bent is in our Durham studios, which is rather unfortunate as we're all down here in London. And in London I have with me Mr Ludovic Grayson, the man who scored all six goals in Arsenal's 1-0 victory over the Turkish Champions FC Botty. (he turns) Ludovic... (pull out to reveal that he is talking to a five-foot-high filing cabinet) first of all, congratulations on the victory.
Mr Grayson | (from inside filing cabinet) Thank you, David.
Presenter | It should send you back to Botty with a big lead.
Mr Grayson | Oh yes, well we're fairly confident, David.
Presenter | Well at the moment, Ludovic, you're crouching down inside a filing cabinet.
Mr Grayson | Yes that's right, David, I'm trying not to be seen.
Presenter | I see. Is this through fear?
Mr Grayson | Oh no, no, it's common sense really. If they can't see you, they can't get you.
Presenter | Ha, ha, ha, but of course they can still hear you. (the filing cabinet explodes) Ludovic Grayson, thank you very much for coming on the program tonight. And we end the show with music. And here with their very latest recording 'Yummy, Yummy, Yummy, I've got love in my tummy' Jackie Charlton and the Tonettes.
| Cut to a trendy pop-music set with coloured lights, etc. On the main podium is a large packing crate with a microphone in front of it. The backing vocal is by three more packing crates with microphones. The instrumental group are also in crates. We hear the aforementioned pop song. Roll credits over; Fade out. Cut to BBC 1 caption.
Voice Over | For those of you who may have just missed 'Monty Python's Flying Circus', here it is again.
| Entire show is recapped in a series of flash clips lasting about twenty seconds.